@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2008 by Barry A. Warsaw
+# Copyright (C) 2004-2010 by Barry A. Warsaw
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public License
@@ -15,8 +15,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 # USA.
 
-__version__ = '1.4.1'
+__version__ = '2.0'
+__all__ = [
+    'Enum',
+    ]
 
-__all__ = ['Enum']
 
 from munepy.enum import Enum
